@@ -1,21 +1,9 @@
 /*
  *  editdlg.cpp  -  dialog to create or modify an alarm or alarm template
  *  Program:  kalarm
- *  Copyright © 2001-2020 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2001-2020 David Jarvie <djarvie@kde.org>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License along
- *  with this program; if not, write to the Free Software Foundation, Inc.,
- *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "editdlg.h"
@@ -82,7 +70,7 @@ inline QString recurText(const KAEvent& event)
 {
     QString r;
     if (event.repetition())
-        r = QStringLiteral("%1 / %2").arg(event.recurrenceText()).arg(event.repetitionText());
+        r = QStringLiteral("%1 / %2").arg(event.recurrenceText(), event.repetitionText());
     else
         r = event.recurrenceText();
     return i18nc("@title:tab", "Recurrence - [%1]", r);
@@ -218,6 +206,7 @@ void EditAlarmDlg::init(const KAEvent* event)
         mTryButton = mButtonBox->addButton(i18nc("@action:button", "Try"), QDialogButtonBox::ActionRole);
         mLoadTemplateButton = mButtonBox->addButton(i18nc("@action:button", "Load Template..."),
                                                     QDialogButtonBox::HelpRole);
+        mLoadTemplateButton->setToolTip(i18nc("@info:tooltip", "Select an alarm template to preset the alarm"));
         mMoreLessButton = mButtonBox->addButton(QDialogButtonBox::RestoreDefaults);
     }
     connect(mButtonBox, &QDialogButtonBox::clicked,
@@ -226,43 +215,25 @@ void EditAlarmDlg::init(const KAEvent* event)
     if (mButtonBox->button(QDialogButtonBox::Ok))
         mButtonBox->button(QDialogButtonBox::Ok)->setWhatsThis(i18nc("@info:whatsthis", "Schedule the alarm at the specified time."));
 
-    QVBoxLayout* mainLayout = new QVBoxLayout(this);
-    if (mTemplate)
-    {
-        QFrame* frame = new QFrame;
-        QHBoxLayout* box = new QHBoxLayout();
-        frame->setLayout(box);
-        box->setContentsMargins(0, 0, 0, 0);
-        QLabel* label = new QLabel(i18nc("@label:textbox", "Template name:"));
-        label->setFixedSize(label->sizeHint());
-        box->addWidget(label);
-        mTemplateName = new QLineEdit();
-        mTemplateName->setReadOnly(mReadOnly);
-        connect(mTemplateName, &QLineEdit::textEdited, this, &EditAlarmDlg::contentsChanged);
-        label->setBuddy(mTemplateName);
-        box->addWidget(mTemplateName);
-        frame->setWhatsThis(i18nc("@info:whatsthis", "Enter the name of the alarm template"));
-        frame->setFixedHeight(box->sizeHint().height());
-        mainLayout->addWidget(frame);
-    }
+    auto* mainLayout = new QVBoxLayout(this);
     mTabs = new QTabWidget(this);
     mainLayout->addWidget(mTabs);
     mTabScrollGroup = new StackedScrollGroup(this, mTabs);
 
-    StackedScrollWidget* mainScroll = new StackedScrollWidget(mTabScrollGroup);
+    auto* mainScroll = new StackedScrollWidget(mTabScrollGroup);
     mTabs->addTab(mainScroll, i18nc("@title:tab", "Alarm"));
     mMainPageIndex = 0;
-    PageFrame* mainPage = new PageFrame(mainScroll);
+    auto* mainPage = new PageFrame(mainScroll);
     mainScroll->setWidget(mainPage);   // mainPage becomes the child of mainScroll
     connect(mainPage, &PageFrame::shown, this, &EditAlarmDlg::slotShowMainPage);
-    QVBoxLayout* topLayout = new QVBoxLayout(mainPage);
+    auto* topLayout = new QVBoxLayout(mainPage);
 
     // Recurrence tab
-    StackedScrollWidget* recurScroll = new StackedScrollWidget(mTabScrollGroup);
+    auto* recurScroll = new StackedScrollWidget(mTabScrollGroup);
     mTabs->addTab(recurScroll, QString());
     mRecurPageIndex = 1;
     QFrame* recurTab = new QFrame;
-    QVBoxLayout* recurTabLayout = new QVBoxLayout();
+    auto* recurTabLayout = new QVBoxLayout();
     recurTab->setLayout(recurTabLayout);
     recurScroll->setWidget(recurTab);   // recurTab becomes the child of recurScroll
     mRecurrenceEdit = new RecurrenceEdit(mReadOnly);
@@ -273,10 +244,31 @@ void EditAlarmDlg::init(const KAEvent* event)
     connect(mRecurrenceEdit, &RecurrenceEdit::repeatNeedsInitialisation, this, &EditAlarmDlg::slotSetSubRepetition);
     connect(mRecurrenceEdit, &RecurrenceEdit::contentsChanged, this, &EditAlarmDlg::contentsChanged);
 
+    if (mTemplate  ||  Preferences::useAlarmName())
+    {
+        // Alarm/template name
+        QFrame* frame = new QFrame;
+        auto* box = new QHBoxLayout();
+        frame->setLayout(box);
+        box->setContentsMargins(0, 0, 0, 0);
+        QLabel* label = new QLabel(mTemplate ? i18nc("@label:textbox", "Template name:") : i18nc("@label:textbox", "Alarm name:"));
+        label->setFixedSize(label->sizeHint());
+        box->addWidget(label);
+        mName = new QLineEdit();
+        mName->setReadOnly(mReadOnly);
+        connect(mName, &QLineEdit::textEdited, this, &EditAlarmDlg::contentsChanged);
+        label->setBuddy(mName);
+        box->addWidget(mName);
+        frame->setWhatsThis(mTemplate ? i18nc("@info:whatsthis", "Enter the name of the alarm template")
+                                      : i18nc("@info:whatsthis", "Enter a name to help you identify this alarm. This is optional and need not be unique."));
+        frame->setFixedHeight(box->sizeHint().height());
+        topLayout->addWidget(frame);
+    }
+
     // Controls specific to the alarm type
     QGroupBox* actionBox = new QGroupBox(i18nc("@title:group", "Action"), mainPage);
     topLayout->addWidget(actionBox, 1);
-    QVBoxLayout* layout = new QVBoxLayout(actionBox);
+    auto* layout = new QVBoxLayout(actionBox);
 
     type_init(actionBox, layout);
 
@@ -285,7 +277,7 @@ void EditAlarmDlg::init(const KAEvent* event)
         // Deferred date/time: visible only for a deferred recurring event.
         mDeferGroup = new QGroupBox(i18nc("@title:group", "Deferred Alarm"), mainPage);
         topLayout->addWidget(mDeferGroup);
-        QHBoxLayout* hlayout = new QHBoxLayout(mDeferGroup);
+        auto* hlayout = new QHBoxLayout(mDeferGroup);
         QLabel* label = new QLabel(i18nc("@label", "Deferred to:"), mDeferGroup);
         label->setFixedSize(label->sizeHint());
         hlayout->addWidget(label);
@@ -300,7 +292,7 @@ void EditAlarmDlg::init(const KAEvent* event)
 //??        mDeferGroup->addSpace(0);
     }
 
-    QHBoxLayout* hlayout = new QHBoxLayout();
+    auto* hlayout = new QHBoxLayout();
     hlayout->setContentsMargins(0, 0, 0, 0);
     topLayout->addLayout(hlayout);
 
@@ -309,7 +301,7 @@ void EditAlarmDlg::init(const KAEvent* event)
     {
         QGroupBox* templateTimeBox = new QGroupBox(i18nc("@title:group", "Time"), mainPage);
         topLayout->addWidget(templateTimeBox);
-        QGridLayout* grid = new QGridLayout(templateTimeBox);
+        auto* grid = new QGridLayout(templateTimeBox);
         mTemplateTimeGroup = new ButtonGroup(templateTimeBox);
         connect(mTemplateTimeGroup, &ButtonGroup::buttonSet, this, &EditAlarmDlg::slotTemplateTimeType);
         connect(mTemplateTimeGroup, &ButtonGroup::buttonSet, this, &EditAlarmDlg::contentsChanged);
@@ -323,7 +315,7 @@ void EditAlarmDlg::init(const KAEvent* event)
         grid->addWidget(mTemplateDefaultTime, 0, 0, Qt::AlignLeft);
 
         QWidget* box = new QWidget(templateTimeBox);
-        QHBoxLayout* layout = new QHBoxLayout(box);
+        auto* layout = new QHBoxLayout(box);
         layout->setContentsMargins(0, 0, 0, 0);
         mTemplateUseTime = new RadioButton(i18nc("@option:radio", "Time:"), box);
         mTemplateUseTime->setFixedSize(mTemplateUseTime->sizeHint());
@@ -364,7 +356,7 @@ void EditAlarmDlg::init(const KAEvent* event)
         mTemplateTimeAfter->setValue(1439);
         mTemplateTimeAfter->setFixedSize(mTemplateTimeAfter->sizeHint());
         mTemplateTimeAfter->setReadOnly(mReadOnly);
-        connect(mTemplateTimeAfter, static_cast<void (TimeSpinBox::*)(int)>(&TimeSpinBox::valueChanged), this, &EditAlarmDlg::contentsChanged);
+        connect(mTemplateTimeAfter, &TimeSpinBox::valueChanged, this, &EditAlarmDlg::contentsChanged);
         mTemplateTimeAfter->setWhatsThis(xi18nc("@info:whatsthis", "<para>%1</para><para>%2</para>",
                                                AlarmTimeWidget::i18n_TimeAfterPeriod(), TimeSpinBox::shiftWhatsThis()));
         layout->addWidget(mTemplateTimeAfter);
@@ -385,7 +377,7 @@ void EditAlarmDlg::init(const KAEvent* event)
     mMoreOptions = new QFrame(mainPage);
     mMoreOptions->setFrameStyle(QFrame::NoFrame);
     topLayout->addWidget(mMoreOptions);
-    QVBoxLayout* moreLayout = new QVBoxLayout(mMoreOptions);
+    auto* moreLayout = new QVBoxLayout(mMoreOptions);
     moreLayout->setContentsMargins(0, 0, 0, 0);
 
     // Reminder
@@ -436,8 +428,8 @@ void EditAlarmDlg::init(const KAEvent* event)
 
     // Initialise the state of all controls according to the specified event, if any
     initValues(event);
-    if (mTemplateName)
-        mTemplateName->setFocus();
+    if (mName)
+        mName->setFocus();
 
     if (!mNewAlarm)
     {
@@ -491,8 +483,8 @@ void EditAlarmDlg::initValues(const KAEvent* event)
     if (event)
     {
         // Set the values to those for the specified event
-        if (mTemplate)
-            mTemplateName->setText(event->templateName());
+        if (mName)
+            mName->setText(event->name());
         bool recurs = event->recurs();
         if ((recurs || event->repetition())  &&  !mTemplate  &&  event->deferred())
         {
@@ -597,6 +589,11 @@ void EditAlarmDlg::initValues(const KAEvent* event)
 /******************************************************************************
 * Initialise various values in the New Alarm dialogue.
 */
+void EditAlarmDlg::setName(const QString& name)
+{
+    if (mName)
+        mName->setText(name);
+}
 void EditAlarmDlg::setTime(const DateTime& start)
 {
     mTimeWidget->setDateTime(start);
@@ -653,9 +650,10 @@ void EditAlarmDlg::saveState(const KAEvent* event)
     mSavedEvent = nullptr;
     if (event)
         mSavedEvent = new KAEvent(*event);
+    if (mName)
+        mSavedName = mName->text();
     if (mTemplate)
     {
-        mSavedTemplateName      = mTemplateName->text();
         mSavedTemplateTimeType  = mTemplateTimeGroup->checkedButton();
         mSavedTemplateTime      = mTemplateTime->time();
         mSavedTemplateAfterTime = mTemplateTimeAfter->value();
@@ -683,12 +681,13 @@ bool EditAlarmDlg::stateChanged() const
     mOnlyDeferred = false;
     if (!mSavedEvent)
         return true;
+    if (mName  &&  mSavedName != mName->text())
+        return true;
     QString textFileCommandMessage;
     checkText(textFileCommandMessage, false);
     if (mTemplate)
     {
-        if (mSavedTemplateName     != mTemplateName->text()
-        ||  mSavedTemplateTimeType != mTemplateTimeGroup->checkedButton()
+        if (mSavedTemplateTimeType != mTemplateTimeGroup->checkedButton()
         ||  (mTemplateUseTime->isChecked()  &&  mSavedTemplateTime != mTemplateTime->time())
         ||  (mTemplateUseTimeAfter->isChecked()  &&  mSavedTemplateAfterTime != mTemplateTimeAfter->value()))
             return true;
@@ -773,7 +772,7 @@ void EditAlarmDlg::setEvent(KAEvent& event, const QString& text, bool trial)
     }
 
     int lateCancel = (trial || !mLateCancel->isEnabled()) ? 0 : mLateCancel->minutes();
-    type_setEvent(event, dt, text, lateCancel, trial);
+    type_setEvent(event, dt, (mName ? mName->text() : QString()), text, lateCancel, trial);
 
     if (!trial)
     {
@@ -814,7 +813,7 @@ void EditAlarmDlg::setEvent(KAEvent& event, const QString& text, bool trial)
         {
             int afterTime = mTemplateDefaultTime->isChecked() ? 0
                           : mTemplateUseTimeAfter->isChecked() ? mTemplateTimeAfter->value() : -1;
-            event.setTemplate(mTemplateName->text(), afterTime);
+            event.setTemplate(mName->text(), afterTime);
         }
     }
 }
@@ -870,7 +869,7 @@ void EditAlarmDlg::showEvent(QShowEvent* se)
 * Called when the window is first shown, to ensure that it initially becomes
 * the active window.
 * This is only required on Ubuntu's Unity desktop, which doesn't transfer
-* keyboard focus properly between Edit Alarm Dialog windows and MessageWin
+* keyboard focus properly between Edit Alarm Dialog windows and MessageWindow
 * windows.
 */
 void EditAlarmDlg::focusFixTimer()
@@ -885,9 +884,9 @@ void EditAlarmDlg::focusFixTimer()
 
 /******************************************************************************
 * Called to detect when the mouse is pressed anywhere inside the window.
-* Activates this window if a MessageWin window is also active.
+* Activates this window if a MessageWindow window is also active.
 * This is only required on Ubuntu's Unity desktop, which doesn't transfer
-* keyboard focus properly between Edit Alarm Dialog windows and MessageWin
+* keyboard focus properly between Edit Alarm Dialog windows and MessageWindow
 * windows.
 */
 bool EditAlarmDlg::eventFilter(QObject*, QEvent* e)
@@ -986,17 +985,17 @@ bool EditAlarmDlg::validate()
     {
         // Check that the template name is not blank and is unique
         QString errmsg;
-        QString name = mTemplateName->text();
+        const QString name = mName->text();
         if (name.isEmpty())
             errmsg = i18nc("@info", "You must enter a name for the alarm template");
-        else if (name != mSavedTemplateName)
+        else if (name != mSavedName)
         {
             if (ResourcesCalendar::templateEvent(name).isValid())
                 errmsg = i18nc("@info", "Template name is already in use");
         }
         if (!errmsg.isEmpty())
         {
-            mTemplateName->setFocus();
+            mName->setFocus();
             KAMessageBox::sorry(this, errmsg);
             return false;
         }
@@ -1178,7 +1177,7 @@ void EditAlarmDlg::slotTry()
             event.setEventId(mEventId);
         }
         type_aboutToTry();
-        void* result = theApp()->execAlarm(event, event.firstAlarm(), KAlarmApp::NoRecordCmdError);
+        void* result = theApp()->execAlarm(event, event.firstAlarm(), KAlarmApp::NoRecordCmdError | KAlarmApp::NoNotifyInhibit);
         type_executedTry(text, result);
     }
 }
@@ -1233,11 +1232,13 @@ void EditAlarmDlg::showOptions(bool more)
     {
         mMoreOptions->show();
         mMoreLessButton->setText(i18nc("@action:Button", "Fewer Options <<"));
+        mMoreLessButton->setToolTip(i18nc("@info:tooltip", "Show fewer options"));
     }
     else
     {
         mMoreOptions->hide();
         mMoreLessButton->setText(i18nc("@action:button", "More Options >>"));
+        mMoreLessButton->setToolTip(i18nc("@info:tooltip", "Show more options"));
     }
     if (mTimeWidget)
         mTimeWidget->showMoreOptions(more);
@@ -1317,14 +1318,14 @@ void EditAlarmDlg::slotShowMainPage()
 {
     if (!mMainPageShown)
     {
-        if (mTemplateName)
-            mTemplateName->setFocus();
+        if (mName)
+            mName->setFocus();
         mMainPageShown = true;
     }
     else
     {
         // Set scroll position to top, since it otherwise jumps randomly
-        StackedScrollWidget* main = static_cast<StackedScrollWidget*>(mTabs->widget(0));
+        auto* main = static_cast<StackedScrollWidget*>(mTabs->widget(0));
         main->verticalScrollBar()->setValue(0);
     }
     if (mTimeWidget)
