@@ -1,21 +1,9 @@
 /*
  *  eventlistview.cpp  -  base class for widget showing list of alarms
  *  Program:  kalarm
- *  Copyright © 2007-2020 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2007-2020 David Jarvie <djarvie@kde.org>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License along
- *  with this program; if not, write to the Free Software Foundation, Inc.,
- *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "eventlistview.h"
@@ -50,7 +38,7 @@ EventListView::EventListView(QWidget* parent)
 
 void EventListView::setModel(QAbstractItemModel* model)
 {
-    EventListModel* elm = qobject_cast<EventListModel*>(model);
+    auto* elm = qobject_cast<EventListModel*>(model);
     Q_ASSERT(elm);   // model must be derived from EventListModel
 
     QTreeView::setModel(model);
@@ -88,20 +76,15 @@ void EventListView::select(const QModelIndex& index, bool scrollToIndex)
         scrollTo(index);
 }
 
-void EventListView::clearSelection()
-{
-    selectionModel()->clearSelection();
-}
-
 /******************************************************************************
 * Return the single selected item.
 * Reply = invalid if no items are selected, or if multiple items are selected.
 */
 QModelIndex EventListView::selectedIndex() const
 {
-    const QModelIndexList list = selectionModel()->selectedRows();
+    const QModelIndexList list = selectionModel()->selectedRows();      //clazy:exclude=inefficient-qlist
     if (list.count() != 1)
-        return QModelIndex();
+        return {};
     return list[0];
 }
 
@@ -111,10 +94,10 @@ QModelIndex EventListView::selectedIndex() const
 */
 KAEvent EventListView::selectedEvent() const
 {
-    const QModelIndexList list = selectionModel()->selectedRows();
+    const QModelIndexList list = selectionModel()->selectedRows();      //clazy:exclude=inefficient-qlist
     if (list.count() != 1)
         return KAEvent();
-    const EventListModel* model = static_cast<const EventListModel*>(list[0].model());
+    const auto* model = static_cast<const EventListModel*>(list[0].model());
     return model->event(list[0]);
 }
 
@@ -124,11 +107,11 @@ KAEvent EventListView::selectedEvent() const
 QVector<KAEvent> EventListView::selectedEvents() const
 {
     QVector<KAEvent> elist;
-    const QModelIndexList ixlist = selectionModel()->selectedRows();
+    const QModelIndexList ixlist = selectionModel()->selectedRows();      //clazy:exclude=inefficient-qlist
     int count = ixlist.count();
     if (count)
     {
-        const EventListModel* model = static_cast<const EventListModel*>(ixlist[0].model());
+        const auto* model = static_cast<const EventListModel*>(ixlist[0].model());
         elist.reserve(count);
         for (int i = 0;  i < count;  ++i)
             elist += model->event(ixlist[i]);
@@ -180,7 +163,7 @@ bool EventListView::viewportEvent(QEvent* e)
 {
     if (e->type() == QEvent::ToolTip  &&  isActiveWindow())
     {
-        QHelpEvent* he = static_cast<QHelpEvent*>(e);
+        auto* he = static_cast<QHelpEvent*>(e);
         const QModelIndex index = indexAt(he->pos());
         QVariant value = model()->data(index, Qt::ToolTipRole);
         if (value.canConvert<QString>())
@@ -189,8 +172,9 @@ bool EventListView::viewportEvent(QEvent* e)
             int i = toolTip.indexOf(QLatin1Char('\n'));
             if (i < 0)
             {
-                EventListModel* m = qobject_cast<EventListModel*>(model());
+                auto* m = qobject_cast<EventListModel*>(model());
                 if (index.column() == ResourceDataModelBase::TextColumn
+                ||  index.column() == ResourceDataModelBase::NameColumn
                 ||  !m  ||  m->event(index).commandError() == KAEvent::CMD_NO_ERROR)
                 {
                     // Single line tooltip. Only display it if the text column
@@ -235,11 +219,11 @@ bool EventListDelegate::editorEvent(QEvent* e, QAbstractItemModel* model, const
             break;
         case QEvent::MouseButtonRelease:
         {
-            EventListView* view = static_cast<EventListView*>(parent());
+            auto* view = static_cast<EventListView*>(parent());
             if (!view->editOnSingleClick()
             ||  !view->style()->styleHint(QStyle::SH_ItemView_ActivateItemOnSingleClick, nullptr, view))
                 return false;
-            QMouseEvent* me = static_cast<QMouseEvent*>(e);
+            auto* me = static_cast<QMouseEvent*>(e);
             if (me->button() != Qt::LeftButton  ||  me->buttons()
             ||  me->modifiers() != Qt::NoModifier)
                 return false;
@@ -251,7 +235,7 @@ bool EventListDelegate::editorEvent(QEvent* e, QAbstractItemModel* model, const
     if (index.isValid())
     {
         qCDebug(KALARM_LOG) << "EventListDelegate::editorEvent";
-        EventListModel* itemModel = qobject_cast<EventListModel*>(model);
+        auto* itemModel = qobject_cast<EventListModel*>(model);
         if (!itemModel)
             qCCritical(KALARM_LOG) << "EventListDelegate::editorEvent: Invalid cast to EventListModel*";
         else
