@@ -1,21 +1,9 @@
 /*
  *  kamail.cpp  -  email functions
  *  Program:  kalarm
- *  Copyright © 2002-2019 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2002-2020 David Jarvie <djarvie@kde.org>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License along
- *  with this program; if not, write to the Free Software Foundation, Inc.,
- *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "kamail.h"
@@ -37,7 +25,6 @@
 #include <MailTransport/TransportManager>
 #include <MailTransport/Transport>
 #include <MailTransportAkonadi/MessageQueueJob>
-#include <KCalendarCore/Person>
 #include <KMime/HeaderParsing>
 #include <KMime/Headers>
 #include <KMime/Message>
@@ -63,7 +50,10 @@
 #include <QStandardPaths>
 #include <QDBusInterface>
 
-#include <pwd.h>
+#ifdef Q_OS_WIN
+#define popen _popen
+#define pclose _pclose
+#endif
 
 static const QLatin1String KMAIL_DBUS_SERVICE("org.kde.kmail");
 //static const QLatin1String KMAIL_DBUS_PATH("/KMail");
@@ -249,7 +239,7 @@ int KAMail::send(JobData& jobdata, QStringList& errmsgs)
             return -1;
         }
 
-        MailTransport::MessageQueueJob* mailjob = new MailTransport::MessageQueueJob(qApp);
+        auto* mailjob = new MailTransport::MessageQueueJob(qApp);
         mailjob->setMessage(message);
         mailjob->transportAttribute().setTransportId(transport->id());
         // MessageQueueJob email addresses must be pure, i.e. without display name. Note
@@ -287,7 +277,7 @@ void KAMail::slotEmailSent(KJob* job)
         errmsgs = errors(job->errorString(), SEND_ERROR);
     }
     JobData jobdata;
-    if (mJobs.isEmpty()  ||  mJobData.isEmpty()  ||  job != mJobs.head())
+    if (mJobs.isEmpty()  ||  mJobData.isEmpty()  ||  job != qAsConst(mJobs).head())
     {
         // The queue has been corrupted, so we can't locate the job's data
         qCCritical(KALARM_LOG) << "KAMail::slotEmailSent: Wrong job at head of queue: wiping queue";
@@ -309,8 +299,9 @@ void KAMail::slotEmailSent(KJob* job)
     if (!mJobs.isEmpty())
     {
         // Send the next queued email
-        connect(mJobs.head(), &KJob::result, instance(), &KAMail::slotEmailSent);
-        mJobs.head()->start();
+        auto job = mJobs.head();
+        connect(job, &KJob::result, instance(), &KAMail::slotEmailSent);
+        job->start();
     }
 }
 
@@ -319,15 +310,15 @@ void KAMail::slotEmailSent(KJob* job)
 */
 void initHeaders(KMime::Message& message, KAMail::JobData& data)
 {
-    KMime::Headers::Date* date = new KMime::Headers::Date;
+    auto* date = new KMime::Headers::Date;
     date->setDateTime(KADateTime::currentDateTime(Preferences::timeSpec()).qDateTime());
     message.setHeader(date);
 
-    KMime::Headers::From* from = new KMime::Headers::From;
+    auto* from = new KMime::Headers::From;
     from->fromUnicodeString(data.from, autoDetectCharset(data.from));
     message.setHeader(from);
 
-    KMime::Headers::To* to = new KMime::Headers::To;
+    auto* to = new KMime::Headers::To;
     const KCalendarCore::Person::List toList = data.event.emailAddressees();
     for (const KCalendarCore::Person& who : toList)
         to->addAddress(who.email().toLatin1(), who.name());
@@ -335,21 +326,21 @@ void initHeaders(KMime::Message& message, KAMail::JobData& data)
 
     if (!data.bcc.isEmpty())
     {
-        KMime::Headers::Bcc* bcc = new KMime::Headers::Bcc;
+        auto* bcc = new KMime::Headers::Bcc;
         bcc->fromUnicodeString(data.bcc, autoDetectCharset(data.bcc));
         message.setHeader(bcc);
     }
 
-    KMime::Headers::Subject* subject = new KMime::Headers::Subject;
+    auto* subject = new KMime::Headers::Subject;
     const QString str = data.event.emailSubject();
     subject->fromUnicodeString(str, autoDetectCharset(str));
     message.setHeader(subject);
 
-    KMime::Headers::UserAgent* agent = new KMime::Headers::UserAgent;
+    auto* agent = new KMime::Headers::UserAgent;
     agent->fromUnicodeString(KAboutData::applicationData().displayName() + QLatin1String("/" KALARM_VERSION), "us-ascii");
     message.setHeader(agent);
 
-    KMime::Headers::MessageID* id = new KMime::Headers::MessageID;
+    auto* id = new KMime::Headers::MessageID;
     id->generate(data.from.mid(data.from.indexOf(QLatin1Char('@')) + 1).toLatin1());
     message.setHeader(id);
 }
@@ -362,7 +353,7 @@ void initHeaders(KMime::Message& message, KAMail::JobData& data)
 QString KAMail::appendBodyAttachments(KMime::Message& message, JobData& data)
 {
     const QStringList attachments = data.event.emailAttachments();
-    if (!attachments.count())
+    if (attachments.isEmpty())
     {
         // There are no attachments, so simply append the message body
         message.contentType()->setMimeType("text/plain");
@@ -382,7 +373,7 @@ QString KAMail::appendBodyAttachments(KMime::Message& message, JobData& data)
         if (!data.event.message().isEmpty())
         {
             // There is a message body
-            KMime::Content* content = new KMime::Content();
+            auto* content = new KMime::Content();
             content->contentType()->setMimeType("text/plain");
             content->contentType()->setCharset("utf-8");
             content->fromUnicodeString(data.event.message());
@@ -444,19 +435,19 @@ QString KAMail::appendBodyAttachments(KMime::Message& message, JobData& data)
             }
 
             QByteArray coded = KCodecs::base64Encode(contents);
-            KMime::Content* content = new KMime::Content();
+            auto* content = new KMime::Content();
             content->setBody(coded + "\n\n");
 
             // Set the content type
             QMimeDatabase mimeDb;
             QString typeName = mimeDb.mimeTypeForUrl(url).name();
-            KMime::Headers::ContentType* ctype = new KMime::Headers::ContentType;
+            auto* ctype = new KMime::Headers::ContentType;
             ctype->fromUnicodeString(typeName, autoDetectCharset(typeName));
             ctype->setName(attachment, "local");
             content->setHeader(ctype);
 
             // Set the encoding
-            KMime::Headers::ContentTransferEncoding* cte = new KMime::Headers::ContentTransferEncoding;
+            auto* cte = new KMime::Headers::ContentTransferEncoding;
             cte->setEncoding(KMime::Headers::CEbase64);
             cte->setDecoded(false);
             content->setHeader(cte);
@@ -673,7 +664,7 @@ QStringList KAMail::errors(const QString& err, ErrType prefix)
 QString KAMail::getMailBody(quint32 serialNumber)
 {
 //TODO: Need to use Akonadi instead
-    const QList<QVariant> args{serialNumber, (int)0};
+    const QList<QVariant> args{serialNumber, (int)0};       //clazy:exclude=inefficient-qlist
     QDBusInterface iface(KMAIL_DBUS_SERVICE, QString(), QStringLiteral("KMailIface"));
     const QDBusReply<QString> reply = iface.callWithArgumentList(QDBus::Block, QStringLiteral("getDecodedBodyPart"), args);
     if (!reply.isValid())
@@ -882,8 +873,7 @@ using namespace KMime::HeaderParsing;
 bool parseUserName( const char* & scursor, const char * const send,
                     QString & result, bool isCRLF ) {
 
-  QString maybeLocalPart;
-  QString tmp;
+  QByteArray atom;
 
   if ( scursor != send ) {
     // first, eat any whitespace
@@ -898,10 +888,14 @@ bool parseUserName( const char* & scursor, const char * const send,
 
     default: // atom
       scursor--; // re-set scursor to point to ch again
-      tmp.clear();
-      if ( parseAtom( scursor, send, result, false /* no 8bit */ ) ) {
-        if (getpwnam(result.toLocal8Bit().constData()))
+      if ( parseAtom( scursor, send, atom, false /* no 8bit */ ) ) {
+          //TODO FIXME on windows
+#ifndef WIN32
+        if (getpwnam(atom.constData())) {
+          result = QLatin1String(atom);
           return true;
+        }
+#endif
       }
       return false; // parseAtom can only fail if the first char is non-atext.
     }
