@@ -1,24 +1,12 @@
 /*
  *  recurrenceedit.cpp  -  widget to edit the event's recurrence definition
  *  Program:  kalarm
- *  Copyright © 2002-2020 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2002-2020 David Jarvie <djarvie@kde.org>
  *
  *  Based originally on KOrganizer module koeditorrecurrence.cpp,
- *  Copyright (c) 2000,2001 Cornelius Schumacher <schumacher@kde.org>
+ *  SPDX-FileCopyrightText: 2000, 2001 Cornelius Schumacher <schumacher@kde.org>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License along
- *  with this program; if not, write to the Free Software Foundation, Inc.,
- *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "recurrenceedit.h"
@@ -82,7 +70,7 @@ RecurrenceEdit::RecurrenceEdit(bool readOnly, QWidget* parent)
     , mReadOnly(readOnly)
 {
     qCDebug(KALARM_LOG) << "RecurrenceEdit:";
-    QVBoxLayout* topLayout = new QVBoxLayout(this);
+    auto* topLayout = new QVBoxLayout(this);
     topLayout->setContentsMargins(0, 0, 0, 0);
 
     /* Create the recurrence rule Group box which holds the recurrence period
@@ -94,13 +82,13 @@ RecurrenceEdit::RecurrenceEdit(bool readOnly, QWidget* parent)
 
     QGroupBox* recurGroup = new QGroupBox(i18nc("@title:group", "Recurrence Rule"), this);
     topLayout->addWidget(recurGroup);
-    QHBoxLayout* hlayout = new QHBoxLayout(recurGroup);
+    auto* hlayout = new QHBoxLayout(recurGroup);
     const int marLeft  = style()->pixelMetric(QStyle::PM_LayoutLeftMargin);
     const int marRight = style()->pixelMetric(QStyle::PM_LayoutRightMargin);
     hlayout->setSpacing((marLeft + marRight)/2);   // use margin spacing due to vertical divider line
 
     // Recurrence period radio buttons
-    QVBoxLayout* vlayout = new QVBoxLayout();
+    auto* vlayout = new QVBoxLayout();
     vlayout->setSpacing(0);
     vlayout->setContentsMargins(0, 0, 0, 0);
     hlayout->addLayout(vlayout);
@@ -241,8 +229,8 @@ RecurrenceEdit::RecurrenceEdit(bool readOnly, QWidget* parent)
     mRepeatCountEntry->setSelectOnStep(false);
     mRepeatCountEntry->setReadOnly(mReadOnly);
     mRepeatCountEntry->setWhatsThis(i18nc("@info:whatsthis", "Enter the total number of times to trigger the alarm"));
-    connect(mRepeatCountEntry, static_cast<void (SpinBox::*)(int)>(&SpinBox::valueChanged), this, &RecurrenceEdit::repeatCountChanged);
-    connect(mRepeatCountEntry, static_cast<void (SpinBox::*)(int)>(&SpinBox::valueChanged), this, &RecurrenceEdit::contentsChanged);
+    connect(mRepeatCountEntry, &SpinBox::valueChanged, this, &RecurrenceEdit::repeatCountChanged);
+    connect(mRepeatCountEntry, &SpinBox::valueChanged, this, &RecurrenceEdit::contentsChanged);
     mRepeatCountButton->setFocusWidget(mRepeatCountEntry);
     mRepeatCountLabel = new QLabel(i18nc("@label", "occurrence(s)"), mRangeButtonBox);
     mRepeatCountLabel->setFixedSize(mRepeatCountLabel->sizeHint());
@@ -833,7 +821,7 @@ void RecurrenceEdit::set(const KAEvent& event)
                 for (const RecurrenceRule::WDayPos& posn : posns)
                 {
                     if (!posn.pos())
-                        rDays.setBit(posn.day() - 1, 1);
+                        rDays.setBit(posn.day() - 1, true);
                 }
                 mWeeklyRule->setDays(rDays);
                 break;
@@ -898,7 +886,7 @@ void RecurrenceEdit::set(const KAEvent& event)
     mExceptionDates = event.recurrence()->exDates();
     std::sort(mExceptionDates.begin(), mExceptionDates.end());
     mExceptionDateList->clear();
-    for (const QDate& exceptionDate : mExceptionDates)
+    for (const QDate& exceptionDate : qAsConst(mExceptionDates))
         new QListWidgetItem(QLocale().toString(exceptionDate, QLocale::LongFormat), mExceptionDateList);
     enableExceptionButtons();
     mExcludeHolidays->setChecked(event.holidaysExcluded());
@@ -1080,12 +1068,12 @@ Rule::Rule(const QString& freqText, const QString& freqWhatsThis, bool time, boo
     mLayout = new QVBoxLayout(this);
     mLayout->setContentsMargins(0, 0, 0, 0);
 
-    QHBoxLayout* freqLayout = new QHBoxLayout();
+    auto* freqLayout = new QHBoxLayout();
     freqLayout->setContentsMargins(0, 0, 0, 0);
     mLayout->addLayout(freqLayout);
     QWidget* box = new QWidget(this);    // this is to control the QWhatsThis text display area
     freqLayout->addWidget(box, 0, Qt::AlignLeft);
-    QHBoxLayout* boxLayout = new QHBoxLayout(box);
+    auto* boxLayout = new QHBoxLayout(box);
     boxLayout->setContentsMargins(0, 0, 0, 0);
 
     QLabel* label = new QLabel(i18nc("@label:spinbox", "Recur e&very"), box);
@@ -1098,6 +1086,8 @@ Rule::Rule(const QString& freqText, const QString& freqWhatsThis, bool time, boo
         mTimeSpinBox->setFixedSize(mTimeSpinBox->sizeHint());
         mTimeSpinBox->setReadOnly(readOnly);
         boxLayout->addWidget(mSpinBox, 0, Qt::AlignLeft);
+        connect(mTimeSpinBox, &SpinBox2::valueChanged, this, &Rule::frequencyChanged);
+        connect(mTimeSpinBox, &SpinBox2::valueChanged, this, &Rule::changed);
     }
     else
     {
@@ -1106,9 +1096,9 @@ Rule::Rule(const QString& freqText, const QString& freqWhatsThis, bool time, boo
         mIntSpinBox->setFixedSize(mIntSpinBox->sizeHint());
         mIntSpinBox->setReadOnly(readOnly);
         boxLayout->addWidget(mSpinBox, 0, Qt::AlignLeft);
+        connect(mIntSpinBox, &QSpinBox::valueChanged, this, &Rule::frequencyChanged);
+        connect(mIntSpinBox, &QSpinBox::valueChanged, this, &Rule::changed);
     }
-    connect(mSpinBox, SIGNAL(valueChanged(int)), SIGNAL(frequencyChanged()));
-    connect(mSpinBox, SIGNAL(valueChanged(int)), SIGNAL(changed()));
     label->setBuddy(mSpinBox);
     label = new QLabel(freqText, box);
     label->setFixedSize(label->sizeHint());
@@ -1173,7 +1163,7 @@ DayWeekRule::DayWeekRule(const QString& freqText, const QString& freqWhatsThis,
     : Rule(freqText, freqWhatsThis, false, readOnly, parent)
     , mSavedDays(7)
 {
-    QGridLayout* grid = new QGridLayout();
+    auto* grid = new QGridLayout();
     grid->setContentsMargins(0, 0, 0, 0);
     grid->setRowStretch(0, 1);
     layout()->addLayout(grid);
@@ -1186,7 +1176,7 @@ DayWeekRule::DayWeekRule(const QString& freqText, const QString& freqWhatsThis,
     // List the days of the week starting at the user's start day of the week.
     // Save the first day of the week, just in case it changes while the dialog is open.
     QWidget* box = new QWidget(this);   // this is to control the QWhatsThis text display area
-    QGridLayout* dgrid = new QGridLayout(box);
+    auto* dgrid = new QGridLayout(box);
     dgrid->setContentsMargins(0, 0, 0, 0);
     QLocale locale;
     for (int i = 0;  i < 7;  ++i)
@@ -1214,7 +1204,7 @@ QBitArray DayWeekRule::days() const
     ds.fill(false);
     for (int i = 0;  i < 7;  ++i)
         if (mDayBox[i]->isChecked())
-            ds.setBit(Locale::localeDayInWeek_to_weekDay(i) - 1, 1);
+            ds.setBit(Locale::localeDayInWeek_to_weekDay(i) - 1, true);
     return ds;
 }
 
@@ -1325,7 +1315,7 @@ MonthYearRule::MonthYearRule(const QString& freqText, const QString& freqWhatsTh
     mButtonGroup = new ButtonGroup(this);
 
     // Month day selector
-    QGridLayout* boxLayout = new QGridLayout();
+    auto* boxLayout = new QGridLayout();
     boxLayout->setContentsMargins(0, 0, 0, 0);
     layout()->addLayout(boxLayout);
 
@@ -1346,7 +1336,7 @@ MonthYearRule::MonthYearRule(const QString& freqText, const QString& freqWhatsTh
     mDayCombo->setReadOnly(readOnly);
     mDayCombo->setWhatsThis(i18nc("@info:whatsthis", "Select the day of the month on which to repeat the alarm"));
     mDayButton->setFocusWidget(mDayCombo);
-    connect(mDayCombo, static_cast<void (ComboBox::*)(int)>(&ComboBox::activated), this, &MonthYearRule::slotDaySelected);
+    connect(mDayCombo, &ComboBox::activated, this, &MonthYearRule::slotDaySelected);
     connect(mDayCombo, static_cast<void (ComboBox::*)(int)>(&ComboBox::currentIndexChanged), this, &MonthYearRule::changed);
     boxLayout->addWidget(mDayCombo, 0, 1, 1, 2, Qt::AlignLeft);
 
@@ -1530,7 +1520,7 @@ YearlyRule::YearlyRule(bool readOnly, QWidget* parent)
            true, readOnly, parent)
 {
     // Set up the month selection widgets
-    QHBoxLayout* hlayout = new QHBoxLayout();
+    auto* hlayout = new QHBoxLayout();
     hlayout->setContentsMargins(0, 0, 0, 0);
     layout()->addLayout(hlayout);
     QLabel* label = new QLabel(i18nc("@label List of months to select", "Months:"), this);
@@ -1540,7 +1530,7 @@ YearlyRule::YearlyRule(bool readOnly, QWidget* parent)
     // List the months of the year.
     QWidget* w = new QWidget(this);   // this is to control the QWhatsThis text display area
     hlayout->addWidget(w, 1, Qt::AlignLeft);
-    QGridLayout* grid = new QGridLayout(w);
+    auto* grid = new QGridLayout(w);
     grid->setContentsMargins(0, 0, 0, 0);
     QLocale locale;
     for (int i = 0;  i < 12;  ++i)
@@ -1556,11 +1546,11 @@ YearlyRule::YearlyRule(bool readOnly, QWidget* parent)
     w->setWhatsThis(i18nc("@info:whatsthis", "Select the months of the year in which to repeat the alarm"));
 
     // February 29th handling option
-    QHBoxLayout* f29box = new QHBoxLayout;
+    auto* f29box = new QHBoxLayout;
     layout()->addLayout(f29box);
     w = new QWidget(this);     // this is to control the QWhatsThis text display area
     f29box->addWidget(w, 0, Qt::AlignLeft);
-    QHBoxLayout* boxLayout = new QHBoxLayout(w);
+    auto* boxLayout = new QHBoxLayout(w);
     boxLayout->setContentsMargins(0, 0, 0, 0);
     mFeb29Label = new QLabel(i18nc("@label:listbox", "February 2&9th alarm in non-leap years:"));
     mFeb29Label->setFixedSize(mFeb29Label->sizeHint());
