@@ -1,21 +1,9 @@
 /*
  *  repetitionbutton.cpp  -  pushbutton and dialog to specify alarm repetition
  *  Program:  kalarm
- *  Copyright © 2004-2019 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2004-2020 David Jarvie <djarvie@kde.org>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License along
- *  with this program; if not, write to the Free Software Foundation, Inc.,
- *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "repetitionbutton.h"
@@ -146,7 +134,7 @@ RepetitionDlg::RepetitionDlg(const QString& caption, bool readOnly, QWidget* par
 {
     setWindowTitle(caption);
 
-    QVBoxLayout* topLayout = new QVBoxLayout(this);
+    auto* topLayout = new QVBoxLayout(this);
 
     mTimeSelector = new TimeSelector(i18nc("@option:check Repeat every 10 minutes", "Repeat every"),
                       i18nc("@info:whatsthis", "Instead of the alarm triggering just once at each recurrence, "
@@ -163,8 +151,8 @@ RepetitionDlg::RepetitionDlg(const QString& caption, bool readOnly, QWidget* par
     mButtonGroup = new ButtonGroup(mButtonBox);
     connect(mButtonGroup, &ButtonGroup::buttonSet, this, &RepetitionDlg::typeClicked);
 
-    QVBoxLayout* vlayout = new QVBoxLayout(mButtonBox);
-    QHBoxLayout* layout = new QHBoxLayout();
+    auto* vlayout = new QVBoxLayout(mButtonBox);
+    auto* layout = new QHBoxLayout();
     layout->setContentsMargins(0, 0, 0, 0);
     vlayout->addLayout(layout);
     mCountButton = new RadioButton(i18nc("@option:radio", "Number of repetitions:"), mButtonBox);
@@ -176,7 +164,7 @@ RepetitionDlg::RepetitionDlg(const QString& caption, bool readOnly, QWidget* par
     mCount->setFixedSize(mCount->sizeHint());
     mCount->setSingleShiftStep(10);
     mCount->setSelectOnStep(false);
-    connect(mCount, static_cast<void (SpinBox::*)(int)>(&SpinBox::valueChanged), this, &RepetitionDlg::countChanged);
+    connect(mCount, &SpinBox::valueChanged, this, &RepetitionDlg::countChanged);
     mCount->setWhatsThis(i18nc("@info:whatsthis", "Enter the number of times to trigger the alarm after its initial occurrence"));
     layout->addWidget(mCount);
     mCountButton->setFocusWidget(mCount);
@@ -198,7 +186,7 @@ RepetitionDlg::RepetitionDlg(const QString& caption, bool readOnly, QWidget* par
     mDurationButton->setFocusWidget(mDuration);
     layout->addStretch();
 
-    QDialogButtonBox* buttonBox = new QDialogButtonBox(this);
+    auto* buttonBox = new QDialogButtonBox(this);
     buttonBox->addButton(QDialogButtonBox::Ok);
     buttonBox->addButton(QDialogButtonBox::Cancel);
     connect(buttonBox, &QDialogButtonBox::accepted,
