@@ -1,21 +1,9 @@
 /*
  *  dirresourceimportdialog.cpp - configuration dialog to import directory resources
  *  Program:  kalarm
- *  Copyright © 2020 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2020 David Jarvie <djarvie@kde.org>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License along
- *  with this program; if not, write to the Free Software Foundation, Inc.,
- *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "dirresourceimportdialog.h"
@@ -31,7 +19,6 @@
 #include <KLocalizedString>
 #include <KIO/StatJob>
 
-#include <QUrl>
 #include <QTimer>
 
 using namespace KAlarmCal;
@@ -136,9 +123,9 @@ void DirResourceImportDialog::pageChanged(KPageWidgetItem* current, KPageWidgetI
 
     if (current)
     {
-        DirResourceImportWidgetBase* page = static_cast<DirResourceImportWidgetBase*>(current->widget());
+        auto* page = static_cast<DirResourceImportWidgetBase*>(current->widget());
         page->setTextSizes();
-        DirResourceImportTypeWidget* typePage = qobject_cast<DirResourceImportTypeWidget*>(page);
+        auto* typePage = qobject_cast<DirResourceImportTypeWidget*>(page);
         if (typePage)
             typePage->validate();
     }
@@ -151,7 +138,7 @@ void DirResourceImportDialog::pageChanged(KPageWidgetItem* current, KPageWidgetI
 */
 void DirResourceImportDialog::typeStatusChanged(bool ok)
 {
-    DirResourceImportTypeWidget* page = qobject_cast<DirResourceImportTypeWidget*>(currentPage()->widget());
+    auto* page = qobject_cast<DirResourceImportTypeWidget*>(currentPage()->widget());
     if (page)
     {
         nextButton()->setEnabled(ok  &&  (page != mLastPage));
@@ -445,7 +432,7 @@ void DirResourceImportTypeWidget::validate()
 */
 void DirResourceImportTypeWidget::slotStatJobResult(KJob* job)
 {
-    KIO::StatJob* statJob = static_cast<KIO::StatJob*>(job);
+    auto* statJob = static_cast<KIO::StatJob*>(job);
     mStatJob = nullptr;
 
     if (!mCheckingDir)
