@@ -1,21 +1,9 @@
 /*
  *  fileresourcemigrator.cpp  -  migrates or creates KAlarm non-Akonadi resources
  *  Program:  kalarm
- *  Copyright © 2011-2020 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2011-2020 David Jarvie <djarvie@kde.org>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License along
- *  with this program; if not, write to the Free Software Foundation, Inc.,
- *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "fileresourcemigrator.h"
@@ -32,7 +20,6 @@
 #include "kalarm_debug.h"
 
 #include <KAlarmCal/CollectionAttribute>
-#include <KAlarmCal/KACalendar>
 #include <KAlarmCal/Version>
 
 #include <AkonadiCore/AgentManager>
@@ -55,6 +42,8 @@
 
 using namespace KAlarmCal;
 
+//clazy:excludeall=non-pod-global-static
+
 namespace
 {
 const QString KALARM_RESOURCE(QStringLiteral("akonadi_kalarm_resource"));
@@ -253,7 +242,7 @@ void FileResourceMigrator::migrateAkonadiResources()
 */
 void FileResourceMigrator::collectionFetchResult(KJob* j)
 {
-    Akonadi::CollectionFetchJob* job = static_cast<Akonadi::CollectionFetchJob*>(j);
+    auto* job = static_cast<Akonadi::CollectionFetchJob*>(j);
     const QString id = job->fetchScope().resource();
     if (j->error())
         qCCritical(KALARM_LOG) << "FileResourceMigrator::collectionFetchResult: CollectionFetchJob" << id << "error: " << j->errorString();
@@ -275,7 +264,7 @@ void FileResourceMigrator::collectionFetchResult(KJob* j)
             QColor backgroundColour;
             if (collection.hasAttribute<CollectionAttribute>())
             {
-                const CollectionAttribute* attr = collection.attribute<CollectionAttribute>();
+                const auto* attr = collection.attribute<CollectionAttribute>();
                 enabledTypes     = attr->enabled();
                 standardTypes    = attr->standard();
                 backgroundColour = attr->backgroundColor();
@@ -293,7 +282,7 @@ void FileResourceMigrator::collectionFetchResult(KJob* j)
 
                 // Update the calendar to the current KAlarm format if necessary,
                 // and if the user agrees.
-                FileResourceCalendarUpdater* updater = new FileResourceCalendarUpdater(resource, true, this);
+                auto* updater = new FileResourceCalendarUpdater(resource, true, this);
                 connect(updater, &QObject::destroyed, this, &FileResourceMigrator::checkIfComplete);
                 updater->update();   // note that 'updater' will auto-delete when finished
 
@@ -485,7 +474,7 @@ void FileResourceMigrator::migrateKResources()
 
             // Update the calendar to the current KAlarm format if necessary,
             // and if the user agrees.
-            FileResourceCalendarUpdater* updater = new FileResourceCalendarUpdater(resource, true, this);
+            auto* updater = new FileResourceCalendarUpdater(resource, true, this);
             connect(updater, &QObject::destroyed, this, &FileResourceMigrator::checkIfComplete);
             updater->update();   // note that 'updater' will auto-delete when finished
 
@@ -538,7 +527,7 @@ void FileResourceMigrator::createCalendar(CalEvent::Type alarmType, const QStrin
 
     // Update the calendar to the current KAlarm format if necessary,
     // and if the user agrees.
-    FileResourceCalendarUpdater* updater = new FileResourceCalendarUpdater(resource, true, this);
+    auto* updater = new FileResourceCalendarUpdater(resource, true, this);
     connect(updater, &QObject::destroyed, this, &FileResourceMigrator::checkIfComplete);
     updater->update();   // note that 'updater' will auto-delete when finished
 }
@@ -559,7 +548,6 @@ bool readDirectoryResource(const QString& dirPath, CalEvent::Types alarmTypes, Q
         return false;
 
     // Read and parse each file in turn
-    QList<QUrl> files;
     QDirIterator it(dir);
     while (it.hasNext())
     {
