@@ -1,28 +1,15 @@
 /*
  *  resourcedatamodelbase.cpp  -  base for models containing calendars and events
  *  Program:  kalarm
- *  Copyright © 2007-2020 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2007-2020 David Jarvie <djarvie@kde.org>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License along
- *  with this program; if not, write to the Free Software Foundation, Inc.,
- *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "resourcedatamodelbase.h"
 
 #include "resources.h"
 
-#include "preferences.h"
 #include "lib/desktop.h"
 #include "lib/messagebox.h"
 #include "kalarm_debug.h"
@@ -138,6 +125,8 @@ QVariant ResourceDataModelBase::headerData(int section, Qt::Orientation orientat
                         return (role == Qt::DisplayRole) ? QString() : i18nc("@title:column", "Color");
                     case TypeColumn:
                         return (role == Qt::DisplayRole) ? QString() : i18nc("@title:column", "Type");
+                    case NameColumn:
+                        return i18nc("@title:column", "Name");
                     case TextColumn:
                         return i18nc("@title:column", "Message, File or Command");
                     case TemplateNameColumn:
@@ -409,6 +398,20 @@ QVariant ResourceDataModelBase::eventData(int role, int column, const KAEvent& e
                         return QStringLiteral("%1").arg(event.actionSubType(), 2, 10, QLatin1Char('0'));
                 }
                 break;
+            case NameColumn:
+            case TemplateNameColumn:
+                switch (role)
+                {
+                    case Qt::BackgroundRole:
+                        calendarColour = true;
+                        break;
+                    case Qt::DisplayRole:
+                    case Qt::ToolTipRole:
+                        return event.name();
+                    case SortRole:
+                        return event.name().toUpper();
+                }
+                break;
             case TextColumn:
                 switch (role)
                 {
@@ -424,18 +427,6 @@ QVariant ResourceDataModelBase::eventData(int role, int column, const KAEvent& e
                         break;
                 }
                 break;
-            case TemplateNameColumn:
-                switch (role)
-                {
-                    case Qt::BackgroundRole:
-                        calendarColour = true;
-                        break;
-                    case Qt::DisplayRole:
-                        return event.templateName();
-                    case SortRole:
-                        return event.templateName().toUpper();
-                }
-                break;
             default:
                 break;
         }
@@ -575,6 +566,8 @@ QString ResourceDataModelBase::whatsThisText(int column)
             return i18nc("@info:whatsthis", "Background color of alarm message");
         case TypeColumn:
             return i18nc("@info:whatsthis", "Alarm type (message, file, command or email)");
+        case NameColumn:
+            return i18nc("@info:whatsthis", "Alarm name, or alarm text if name is blank");
         case TextColumn:
             return i18nc("@info:whatsthis", "Alarm message text, URL of text file to display, command to execute, or email subject line");
         case TemplateNameColumn:
