@@ -2,25 +2,12 @@
  *  singlefileresource.cpp  -  calendar resource held in a single file
  *  Program:  kalarm
  *  Partly based on ICalResourceBase and SingleFileResource in kdepim-runtime.
- *  Copyright © 2009-2020 David Jarvie <djarvie@kde.org>
- *  Copyright (c) 2008 Bertjan Broeksema <broeksema@kde.org>
- *  Copyright (c) 2008 Volker Krause <vkrause@kde.org>
- *  Copyright (c) 2006 Till Adam <adam@kde.org>
+ *  SPDX-FileCopyrightText: 2009-2020 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2008 Bertjan Broeksema <broeksema@kde.org>
+ *  SPDX-FileCopyrightText: 2008 Volker Krause <vkrause@kde.org>
+ *  SPDX-FileCopyrightText: 2006 Till Adam <adam@kde.org>
  *
- *  This library is free software; you can redistribute it and/or modify it
- *  under the terms of the GNU Library General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or (at your
- *  option) any later version.
- *
- *  This library is distributed in the hope that it will be useful, but WITHOUT
- *  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
- *  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
- *  License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to the
- *  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
- *  02110-1301, USA.
+ *  SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #include "singlefileresource.h"
@@ -97,7 +84,7 @@ SingleFileResource::SingleFileResource(FileResourceSettings* settings)
 SingleFileResource::~SingleFileResource()
 {
     qCDebug(KALARM_LOG) << "SingleFileResource::~SingleFileResource" << displayName();
-    close();
+    SingleFileResource::close();    // avoid call to virtual method in destructor
 }
 
 bool SingleFileResource::readOnly() const
